@@ -37,7 +37,7 @@ public:
             // vibrate
         interface  = new QDBusInterface(MCE_SERVICE, MCE_REQUEST_PATH,
                                                 MCE_REQUEST_IF, QDBusConnection::systemBus(),
-                                                0);
+                                                parent);
 /*        QDBusMessage reply = interface->call(MCE_ENABLE_VIBRATOR);
         if (reply.type() == QDBusMessage::ErrorMessage)
                 qDebug() << reply.errorMessage(); */
